``ConversionInterface.convert`` no longer needs to accept unitless values
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Previously, custom subclasses of `.units.ConversionInterface` needed to
implement a ``convert`` method that not only accepted instances of the
unit, but also unitless values (which are passed through as is).  This is
no longer the case (``convert`` is never called with a unitless value),
and such support in `.StrCategoryConverter` is deprecated.  Likewise, the
`.ConversionInterface.is_numlike` helper is deprecated.

Consider calling `.Axis.convert_units` instead, which still supports unitless
values.
